@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Auxiliary.h 1999 2006-11-13 12:52:06Z svn $
+ * $Id: Auxiliary.h 2317 2006-12-28 16:07:10Z svn $
  *****************************************************************************/
 
 #ifndef AUXILIARY_H
@@ -41,7 +41,6 @@
 #include "apr_time.h"
 #include "apr_shm.h"
 
-using namespace std;
 
 /**
  * アトミック関数を初期化します．
@@ -111,17 +110,24 @@ apr_size_t bit_width(apr_size_t x);
  * @return 数値
  */
 apr_size_t atosize(const char *s);
+/**
+ * ファイルの名前から拡張子を求めます．
+ *
+ * @param[in] file_name ファイルの名前
+ * @return ファイルの拡張子
+ */
+const char *get_file_ext(const char *file_name);
 /**
  * ファイルの MIME タイプから画像の拡張子を求めます．
  *
- * @param[in] ファイルの MIME タイプ
+ * @param[in] file_mime ファイルの MIME タイプ
  * @return ファイルの拡張子
  */
 const char *get_mime_image_ext(const char *file_mime);
 /**
  * ファイルの名前から MIME タイプを求めます．
  *
- * @param[in] ファイルの名前
+ * @param[in] file_name ファイルの名前
  * @return ファイルの MIME タイプ
  */
 const char *get_image_mime(const char *file_name);
@@ -160,6 +166,14 @@ void escape_html(apr_pool_t *pool,
  * @return エスケープされた文字列
  */
 const char *escape_html(apr_pool_t *pool, const char *str);
+/**
+ * サイズを文字列で表します．
+ *
+ * @param[in] pool プール
+ * @param[in] size サイズ
+ * @return サイズ文字列
+ */
+const char *size_str(apr_pool_t *pool, apr_uint64_t size);
 #ifndef HAVE_STRNCHR
 /**
  * 文字列の中から指定された文字の位置を探します，
