@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BBSCommentIterator.h 1937 2006-11-07 11:45:41Z svn $
+ * $Id: BBSCommentIterator.h 2327 2006-12-29 18:07:16Z svn $
  *****************************************************************************/
 
 #ifndef BBS_COMMENT_ITERATOR_H
@@ -71,44 +71,44 @@ public:
      *
      * @param[out] bcomment_p コメント
      */
-    void get_comment(BBSThread::bbs_comment_p_t *bcomment_p) const throw();
+    void get_comment(BBSThread::bbs_comment_p_t *bcomment_p) const;
     /**
-     * 次の現在位置を次のコメントに移動させます．
+     * 現在位置を次のコメントに移動させます．
      *
      * @retval true 成功した場合
      * @retval false 失敗した場合（現在位置が最後のコメント）
      */
-    bool go_next() throw();
+    bool go_next();
     /**
      * 読み出し位置をリセットします．
      */
-    void reset() throw();
+    void reset();
 
-    const char *get_version() const throw()
+    const char *get_version() const
     {
         return bbs_thread_->get_version();
     }
-    apr_size_t get_id() const throw()
+    apr_size_t get_id() const
     {
         return bbs_thread_->get_id();
     }
-    apr_time_t get_mtime() const throw()
+    apr_time_t get_mtime() const
     {
         return bbs_thread_->get_mtime();
     }
-    apr_time_t get_atime() const throw()
+    apr_time_t get_atime() const
     {
         return bbs_thread_->get_atime();
     }
-    const char *get_subject() const throw()
+    const char *get_subject() const
     {
         return bbs_thread_->get_subject();
     }
-    apr_size_t get_comment_count() const throw()
+    apr_size_t get_comment_count() const
     {
         return bbs_thread_->get_comment_count();
     }
-    apr_size_t get_size() const throw()
+    apr_size_t get_size() const
     {
         return size_;
     }
