@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BBSCommentVariableCreator.h 1946 2006-11-07 16:35:18Z svn $
+ * $Id: BBSCommentVariableCreator.h 2327 2006-12-29 18:07:16Z svn $
  *****************************************************************************/
 
 #ifndef BBS_COMMENT_VARIABLE_CREATOR_H
@@ -53,7 +53,7 @@ public:
     TemplateVariable::variable_t *create(apr_pool_t *pool,
                                          BBSThread::bbs_comment_p_t *bcomment_p,
                                          void *var_memory,
-                                         void *sca_memory) const throw();
+                                         void *sca_memory) const;
     TemplateVariable::variable_t *create_navi(apr_pool_t *pool,
                                               BBSCommentIterator *comment_iter) const;
     static BBSCommentVariableCreator *get_instance(void *memory,
