@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BBSThreadList.h 1957 2006-11-11 02:41:33Z svn $
+ * $Id: BBSThreadList.h 2063 2006-11-24 14:09:34Z svn $
  *****************************************************************************/
 
 #ifndef BBS_THREAD_LIST_H
@@ -40,7 +40,7 @@
 using namespace std;
 
 /**
- * @brief BBS のスレッドのリストを表すクラス．
+ * @brief 掲示板のスレッドのリストを表すクラス．
  */
 class BBSThreadList: public Uncopyable
 {
@@ -67,7 +67,7 @@ public:
     void get_info_list(BBSThread::info_t *info_list,
                        apr_size_t *info_list_size);
     /**
-     * BBS のスレッド ID のリストを表示順にソートして返します．
+     * 掲示板のスレッド ID のリストを表示順にソートして返します．
      *
      * @param[in] pool プール
      * @param[out] ids ID のリスト
@@ -80,7 +80,7 @@ public:
 #pragma warning(push)
 #pragma warning(disable:4267)
 #endif
-        ASSERT_LESS(i, info_list_size_);
+        ASSERT_LESS(i, *info_list_size_);
 #ifdef _MSC_VER
 #pragma warning(pop)
 #endif
@@ -89,7 +89,7 @@ public:
     };
     apr_size_t get_size() const
     {
-        return info_list_size_;
+        return *info_list_size_;
     };
     apr_time_t get_mtime() const
     {
@@ -136,13 +136,13 @@ private:
 
     static void load_info(BBSThread *bbs_thread, BBSThread::info_t *info);
 
-    static void dump_info(apr_pool_t *pool, BBSThread::info_t *thread_info);
+    static void dump_info(apr_pool_t *pool, BBSThread::info_t *info);
     static void dump_date(apr_pool_t *pool, apr_time_t time);
 
     friend class BBSThreadManager;
 
     BBSThread::info_t *info_list_;
-    apr_size_t info_list_size_;
+    apr_size_t *info_list_size_;
     apr_time_t *mtime_;
 };
 
