@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BBSThreadVariableCreator.h 1945 2006-11-07 14:54:54Z svn $
+ * $Id: BBSThreadVariableCreator.h 2327 2006-12-29 18:07:16Z svn $
  *****************************************************************************/
 
 #ifndef BBS_THREAD_VARIABLE_CREATOR_H
@@ -91,11 +91,11 @@ private:
     TemplateVariable::variable_t *create_info(apr_pool_t *pool,
                                               BBSThread::info_t *thread_info,
                                               void *var_memory,
-                                              void *sca_memory) const throw();
+                                              void *sca_memory) const;
     void set_range(BBSThread::info_t *thread_info,
                    apr_size_t comment_count,
                    BBSCommentIterator::range_t *range,
-                   apr_size_t *range_count) const throw();
+                   apr_size_t *range_count) const;
 
     apr_size_t get_thread_array_memory_size(apr_size_t list_size) const;
     apr_size_t get_info_array_memory_size(apr_size_t list_size) const;
