@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostFlowController.h 1981 2006-11-12 06:40:26Z svn $
+ * $Id: PostFlowController.h 2317 2006-12-28 16:07:10Z svn $
  *****************************************************************************/
 
 #ifndef POST_FLOW_CONTROLLER_H
@@ -34,44 +34,42 @@
 
 #include "apr_shm.h"
 #include "apr_time.h"
+#include "apr_network_io.h"
 #include "AtomicWrapper.h"
 
+#include "FlowController.h"
 #include "Macro.h"
 #include "Uncopyable.h"
 
-using namespace std;
 
 /**
  * @brief 書き込みのフロー制御を行うクラス．
  */
-class PostFlowController: public Uncopyable
+class PostFlowController: public FlowController
 {
 public:
     PostFlowController(apr_size_t min_post_interval_sec);
-    bool can_post(const char *ip_address);
-    void regist_post(const char *ip_address);
+    bool can_post(apr_sockaddr_t *sockaddr);
+    void regist_post(apr_sockaddr_t *sockaddr);
     static PostFlowController *get_instance(apr_shm_t *shm,
                                             apr_size_t min_post_interval_sec);
     static apr_size_t get_memory_size();
 
-    static void dump_list(PostFlowController *flow_controller);
+    static const char *dump_list(apr_pool_t *pool,
+                                 PostFlowController *flow_controller);
 
 private:
-    static const apr_size_t MAX_ADDRESS_LENGTH          = 40;
-    static const apr_size_t BUSY;
-    static const apr_size_t FREE;
-
     typedef struct Poster {
-        char ip_address[MAX_ADDRESS_LENGTH+1]; // パスカル文字列
+        char paddress[MAX_PADDRESS_SIZE]; // パスカル文字列
         apr_time_t time;
     } poster_t;
 
-    void poster_list_add(const char *ip_address, char ip_address_length);
+    void poster_list_add(apr_sockaddr_t *sockaddr);
     void poster_list_clean();
-    apr_time_t poster_list_is_contain(const char *ip_address,
-                                      char ip_address_length) const;
+    bool poster_list_is_contain(apr_sockaddr_t *sockaddr,
+                                apr_time_t time_limit) const;
 
-    static void dump_poster(poster_t *poster);
+    static const char *dump_poster(apr_pool_t *pool, poster_t *poster);
 
     apr_atomic_t lock_;
     apr_time_t min_post_interval_time_;
