@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ReadWriteLocker.h 1981 2006-11-12 06:40:26Z svn $
+ * $Id: ReadWriteLocker.h 2317 2006-12-28 16:07:10Z svn $
  *****************************************************************************/
 
 #ifndef READ_WRITE_LOCKER_H
@@ -47,6 +47,9 @@
  */
 class ReadWriteLocker: public Uncopyable
 {
+public:
+    static const apr_uint32_t NOT_LOCKER        = 0x000000;
+
 protected:
     /**
      * コンストラクタです．
@@ -83,7 +86,7 @@ protected:
     // 注意: ReadWriteLocker 型のポインタ経由で使用されることはないので，
     // デストラクタは virtual にしない．
 
-    // apr_atomic_t に 24bit の制限があるので
+    // apr_atomic_t に 24bit の制限があるので (APR 0.9.*)
     static const apr_uint32_t WRITE_LOCKED      = 0xFFFFFF;
 
     /** 読み出し中のスレッドの数へのポインタ */
