@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Auxiliary.cpp 2004 2006-11-13 14:07:01Z svn $
+ * $Id: Auxiliary.cpp 2317 2006-12-28 16:07:10Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -47,7 +47,9 @@
 
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2004 2006-11-13 14:07:01Z svn $");
+using namespace std;
+
+SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2317 2006-12-28 16:07:10Z svn $");
 
 void init_atomic(apr_pool_t *pool)
 {
@@ -161,7 +163,7 @@ apr_size_t bit_width(apr_size_t x)
             return i;
         }
 
-        j /= 2;
+        j >>= 1;
     }
 
     return (sizeof(apr_size_t) * 8);
@@ -172,6 +174,29 @@ apr_size_t atosize(const char *s)
     return static_cast<apr_size_t>(apr_atoi64(s));
 }
 
+const char *get_file_ext(const char *file_name)
+{
+    const char *file_ext;
+    apr_size_t name_length;
+
+    name_length = strlen(file_name);
+    if (name_length == 0 ) {
+        return "";
+    }
+
+    for (file_ext = file_name+name_length-1; file_ext != file_name;
+         file_ext--) {
+        if (*file_ext == '.') {
+            return ++file_ext;
+        }
+        if (!isalnum(static_cast<unsigned char>(*file_ext))) {
+            return "";
+        }
+    }
+
+    return "";
+}
+
 const char *get_mime_image_ext(const char *file_mime)
 {
     if (strcmp(file_mime, "image/bmp") == 0) {
@@ -193,10 +218,7 @@ const char *get_image_mime(const char *file_name)
 {
     const char *file_ext;
 
-    if ((file_ext = strrchr(file_name, '.')) == NULL) {
-        THROW(MESSAGE_FILE_EXT_INVALID);
-    }
-    file_ext++;
+    file_ext = get_file_ext(file_name);
 
     if (strcmp(file_ext, "bmp") == 0) {
         return "image/bmp";
@@ -314,6 +336,22 @@ const char *escape_html(apr_pool_t *pool, const char *str)
     return escaped_str;
 }
 
+const char *size_str(apr_pool_t *pool, apr_uint64_t size)
+{
+    if (size < 1024) {
+        return apr_psprintf(pool, "%" APR_UINT64_T_FMT " %s", size, BYTE_UNIT);
+    } else if (size < 1024*1024) {
+        return apr_psprintf(pool, "%.1f %s",
+                            static_cast<double>(size)/1024, KBYTE_UNIT);
+    } else if (size < 1024*1024*1024) {
+        return apr_psprintf(pool, "%.1f %s",
+                            static_cast<double>(size/1024)/1024, MBYTE_UNIT);
+    } else {
+        return apr_psprintf(pool, "%.1f %s",
+                            static_cast<double>(size/(1024*1024))/1024, GBYTE_UNIT);
+    }
+}
+
 #ifndef HAVE_STRNCHR
 const char *strnchr(const char *s, size_t length, int c)
 {
