@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BBSCommentIterator.cpp 1887 2006-10-22 18:49:12Z svn $
+ * $Id: BBSCommentIterator.cpp 2327 2006-12-29 18:07:16Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -38,7 +38,7 @@
 #include "BBSThreadReader.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: BBSCommentIterator.cpp 1887 2006-10-22 18:49:12Z svn $");
+SOURCE_INFO_ADD("$Id: BBSCommentIterator.cpp 2327 2006-12-29 18:07:16Z svn $");
 
 const apr_size_t BBSCommentIterator::MEMORY_SIZE        =
     max(sizeof(MmapCommentIterator), sizeof(ShmCommentIterator));
@@ -48,7 +48,7 @@ const apr_uint16_t BBSCommentIterator::RANGE_FROM_LAST  = 0xf000;
  * public メソッド
  *****************************************************************************/
 BBSCommentIterator::BBSCommentIterator(BBSThread *bbs_thread,
-   	                                   range_t *ranges,
+                                       range_t *ranges,
                                        apr_size_t range_count)
   : bbs_thread_(bbs_thread),
     ranges_(ranges),
@@ -70,12 +70,12 @@ BBSCommentIterator::~BBSCommentIterator()
 
 }
 
-void BBSCommentIterator::get_comment(BBSThread::bbs_comment_p_t *bcomment_p) const throw()
+void BBSCommentIterator::get_comment(BBSThread::bbs_comment_p_t *bcomment_p) const
 {
     BBSThread::fill_bcomment_p(curr_no_, bcomment_, bcomment_p);
 }
 
-bool BBSCommentIterator::go_next() throw()
+bool BBSCommentIterator::go_next()
 {
     if (LIKELY(curr_no_ != stop_no_)) {
         curr_no_++;
@@ -95,7 +95,7 @@ bool BBSCommentIterator::go_next() throw()
     return true;
 }
 
-void BBSCommentIterator::reset() throw()
+void BBSCommentIterator::reset()
 {
     curr_index_ = 0;
     curr_no_ = init_curr_no_;
