@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BBSCommentVariableCreator.cpp 1946 2006-11-07 16:35:18Z svn $
+ * $Id: BBSCommentVariableCreator.cpp 2327 2006-12-29 18:07:16Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -33,7 +33,7 @@
 #include "Message.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: BBSCommentVariableCreator.cpp 1946 2006-11-07 16:35:18Z svn $");
+SOURCE_INFO_ADD("$Id: BBSCommentVariableCreator.cpp 2327 2006-12-29 18:07:16Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -86,7 +86,7 @@ inline TemplateVariable::variable_t *
 BBSCommentVariableCreator::create(apr_pool_t *pool,
                                   BBSThread::bbs_comment_p_t *bcomment_p,
                                   void *var_memory,
-                                  void *sca_memory) const throw()
+                                  void *sca_memory) const
 {
     variable_t *comment_var;
     scalar_t *comment_sca;
@@ -234,7 +234,7 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
     tmpl_file_path = argv[3];
 
     if (!is_exist(pool, data_dir_path)) {
-        THROW(MESSAGE_DAT_DIR_NOT_FOUND);
+        THROW(MESSAGE_DATA_DIR_NOT_FOUND);
     }
     if (!is_exist(pool, tmpl_file_path)) {
         THROW(MESSAGE_TMPL_FILE_NOT_FOUND);
