@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BBSThreadList.cpp 1995 2006-11-12 06:56:20Z svn $
+ * $Id: BBSThreadList.cpp 2063 2006-11-24 14:09:34Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -35,10 +35,11 @@
 
 #include "BBSThreadList.h"
 #include "Message.h"
+#include "Macro.h"
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: BBSThreadList.cpp 1995 2006-11-12 06:56:20Z svn $");
+SOURCE_INFO_ADD("$Id: BBSThreadList.cpp 2063 2006-11-24 14:09:34Z svn $");
 
 #define AS_BINFO_T(pointer) reinterpret_cast<BBSThread::info_t *>(pointer)
 #define AS_BTHREAD_T(pointer) reinterpret_cast<BBSThread::bbs_thread_t *>(pointer)
@@ -48,8 +49,7 @@ SOURCE_INFO_ADD("$Id: BBSThreadList.cpp 1995 2006-11-12 06:56:20Z svn $");
  * public メソッド
  *****************************************************************************/
 BBSThreadList::BBSThreadList(apr_shm_t *shm)
-  : info_list_(0),
-    info_list_size_(0)
+  : info_list_(0)
 {
 #ifdef DEBUG
     if (apr_shm_size_get(shm) != get_memory_size()) {
@@ -59,6 +59,7 @@ BBSThreadList::BBSThreadList(apr_shm_t *shm)
 
     init_shm();
 
+    *info_list_size_ = 0;
     *mtime_ = 0;
 }
 
@@ -72,13 +73,13 @@ void BBSThreadList::update(BBSThread *bbs_thread)
 
     // MEMO: i が頻繁に大きな値をとるとパフォーマンスが低下
 
-    for (i = 0; i < info_list_size_; i++) {
+    for (i = 0; i < *info_list_size_; i++) {
         if (bbs_thread->get_id() == info_list_[i].id) {
             break;
         }
     }
 
-    if (i == info_list_size_) { // リスト中に存在しない
+    if (i == *info_list_size_) { // リスト中に存在しない
         add(bbs_thread);
     }
 
@@ -109,25 +110,25 @@ void BBSThreadList::add(BBSThread *bbs_thread)
 
     i = get_insert_index(bbs_thread);
 
-    if (i == info_list_size_) {
-        if (info_list_size_ == LST_MAX_THREAD_COUNT) { // 追加する必要なし
+    if (i == *info_list_size_) {
+        if (*info_list_size_ == LST_MAX_THREAD_COUNT) { // 追加する必要なし
             return;
         } else { // 末尾に追加
-            load_info(bbs_thread, info_list_ + info_list_size_);
+            load_info(bbs_thread, info_list_ + *info_list_size_);
         }
     } else {
         memmove(info_list_ + i + 1, info_list_ + i,
-                sizeof(BBSThread::info_t) * (info_list_size_ - i));
+                sizeof(BBSThread::info_t) * (*info_list_size_ - i));
         load_info(bbs_thread, info_list_ + i);
     }
 
-    info_list_size_++;
+    (*info_list_size_)++;
 }
 
 void BBSThreadList::get_info_list(BBSThread::info_t *info_list,
                                   apr_size_t *info_list_size)
 {
-    *info_list_size = min(*info_list_size, info_list_size_);
+    *info_list_size = min(*info_list_size, *info_list_size_);
 
     memcpy(info_list, info_list_,
            sizeof(BBSThread::info_t) * (*info_list_size));
@@ -136,7 +137,7 @@ void BBSThreadList::get_info_list(BBSThread::info_t *info_list,
 void BBSThreadList::get_ids(apr_pool_t *pool, apr_size_t *ids,
                             apr_uint16_t *count)
 {
-    *count = min(*count, static_cast<apr_uint16_t>(info_list_size_));
+    *count = min(*count, static_cast<apr_uint16_t>(*info_list_size_));
 
     for (apr_uint16_t i = 0; i < *count; i++) {
         ids[i] = info_list_[i].id;
@@ -167,13 +168,13 @@ apr_size_t BBSThreadList::get_memory_size()
 {
     return sizeof(BBSThreadList) +
         (sizeof(BBSThread::info_t)*LST_MAX_THREAD_COUNT) +
-        sizeof(apr_time_t);
+        sizeof(apr_size_t) + sizeof(apr_time_t);
 }
 
 void BBSThreadList::dump_info_list(apr_pool_t *pool,
                                    BBSThreadList *thread_list)
 {
-    for (apr_size_t i = 0; i < thread_list->info_list_size_; i++) {
+    for (apr_size_t i = 0; i < *(thread_list->info_list_size_); i++) {
         dump_info(pool, thread_list->info_list_ + i);
     }
 }
@@ -190,7 +191,8 @@ void BBSThreadList::child_init_impl()
 void BBSThreadList::init_shm()
 {
     info_list_ = AS_BINFO_T(this + 1);
-    mtime_ = AS_TIME(info_list_ + LST_MAX_THREAD_COUNT);
+    info_list_size_ = AS_SIZE(info_list_ + LST_MAX_THREAD_COUNT);
+    mtime_ = AS_TIME(info_list_size_ + 1);
 
 #ifdef __INTEL_COMPILER
 #pragma warning(disable:1684)
@@ -212,7 +214,7 @@ apr_size_t BBSThreadList::get_insert_index(BBSThread *bbs_thread) const
 {
     apr_size_t i;
 
-    for (i = 0; i < info_list_size_; i++) {
+    for (i = 0; i < *info_list_size_; i++) {
         if (bbs_thread->get_atime() >= info_list_[i].atime) {
             return i;
         }
