@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BBSThreadListReader.cpp 1981 2006-11-12 06:40:26Z svn $
+ * $Id: BBSThreadListReader.cpp 2050 2006-11-24 04:08:11Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -43,7 +43,7 @@
 #include "Message.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: BBSThreadListReader.cpp 1981 2006-11-12 06:40:26Z svn $");
+SOURCE_INFO_ADD("$Id: BBSThreadListReader.cpp 2050 2006-11-24 04:08:11Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -175,7 +175,7 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
     }
 
     if (!is_exist(pool, data_dir_path)) {
-        THROW(MESSAGE_DAT_DIR_NOT_FOUND);
+        THROW(MESSAGE_DATA_DIR_NOT_FOUND);
     }
 
     shm = create_shm(pool, BBSThreadList::get_memory_size());
@@ -202,5 +202,4 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
 // Local Variables:
 // mode: c++
 // coding: utf-8-dos
-
 // End:
