@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BBSThreadManager.cpp 1959 2006-11-11 03:05:17Z svn $
+ * $Id: BBSThreadManager.cpp 2327 2006-12-29 18:07:16Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -48,13 +48,13 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: BBSThreadManager.cpp 1959 2006-11-11 03:05:17Z svn $");
+SOURCE_INFO_ADD("$Id: BBSThreadManager.cpp 2327 2006-12-29 18:07:16Z svn $");
 
 #ifdef DEBUG
 #include <iostream>
 #endif
 
-#define AS_BOOL(pointer) reinterpret_cast<bool *>(pointer)
+#define AS_BOOL(pointer)            reinterpret_cast<bool *>(pointer)
 #define AS_BTHREAD_MANAGER(pointer) reinterpret_cast<BBSThreadManager *>(pointer)
 
 #ifdef DEBUG
@@ -73,7 +73,7 @@ SOURCE_INFO_ADD("$Id: BBSThreadManager.cpp 1959 2006-11-11 03:05:17Z svn $");
 #define REQUIRE_MANAGER_LOCKED()                                \
     do {                                                        \
         if (!ReadLocker::is_locked(manager_ref_count_)) {      \
-            throw MESSAGE_BBS_SHOULD_LOCKED                     \
+            throw MESSAGE_MANAGER_SHOULD_LOCKED                 \
                 " (" __FILE__ ":" APR_STRINGIFY(__LINE__) ")";  \
         }                                                       \
     } while (0)
@@ -303,16 +303,16 @@ BBSThreadManager *BBSThreadManager::child_init(apr_shm_t *shm,
 apr_size_t BBSThreadManager::get_memory_size()
 {
     return sizeof(BBSThreadManager) +
-        (BBSThread::MAX_THREAD_DATA_SIZE + sizeof(apr_size_t)
-         + sizeof(apr_uint16_t) + sizeof(apr_uint16_t) + sizeof(apr_atomic_t)) *
+        (BBSThread::MAX_THREAD_DATA_SIZE + sizeof(apr_size_t) +
+         sizeof(apr_uint16_t) + sizeof(apr_uint16_t) + sizeof(apr_atomic_t)) *
         MGR_ON_MEMORY_THREAD_COUNT +
-        sizeof(apr_uint16_t) + sizeof(apr_atomic_t);
+        sizeof(apr_atomic_t) + sizeof(apr_uint16_t);
 }
 
 void BBSThreadManager::check_finalize_state(BBSThreadManager *thread_manager)
 {
     if (ReadLocker::is_locked(thread_manager->manager_ref_count_)) {
-        THROW(MESSAGE_BBS_SHOULD_NOT_LOCKED);
+        THROW(MESSAGE_MANAGER_SHOULD_NOT_LOCKED);
     }
 
     for (apr_size_t i = 0; i < *(thread_manager->thread_count_); i++) {
@@ -366,7 +366,7 @@ void BBSThreadManager::init_shm()
 #ifdef __INTEL_COMPILER
 #pragma warning(disable:1684)
 #endif
-    ASSERT_EQUAL(AS_CHAR(thread_count_) + sizeof(*thread_count_),
+    ASSERT_EQUAL(AS_CHAR(thread_count_ + 1),
                  AS_CHAR(threads_) +
                  (get_memory_size() - sizeof(BBSThreadManager)));
 #ifdef __INTEL_COMPILER
@@ -860,7 +860,7 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
     data_dir_path = argv[1];
 
     if (!is_exist(pool, data_dir_path)) {
-        THROW(MESSAGE_DAT_DIR_NOT_FOUND);
+        THROW(MESSAGE_DATA_DIR_NOT_FOUND);
     }
 
     manager_shm = create_shm(pool, BBSThreadManager::get_memory_size());
