@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BBSThreadReader.cpp 1898 2006-10-26 17:46:14Z svn $
+ * $Id: BBSThreadReader.cpp 2038 2006-11-23 18:21:20Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -39,7 +39,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: BBSThreadReader.cpp 1898 2006-10-26 17:46:14Z svn $");
+SOURCE_INFO_ADD("$Id: BBSThreadReader.cpp 2038 2006-11-23 18:21:20Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -131,8 +131,6 @@ inline void BBSThreadReader::check_format(apr_mmap_t *bthread_file_map)
     if (bthread_file_map->size < sizeof(BBSThread)) {
         THROW(MESSAGE_BBS_THREAD_FORMAT_INVALID);
     } else if (bthread_file_map->size != bbs_thread->get_valid_size()) {
-        cout << bthread_file_map->size << endl;
-        cout << bbs_thread->get_valid_size() << endl;
         THROW(MESSAGE_BBS_THREAD_FORMAT_INVALID);
     }
 
