@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BBSThreadVariableCreator.cpp 1945 2006-11-07 14:54:54Z svn $
+ * $Id: BBSThreadVariableCreator.cpp 2327 2006-12-29 18:07:16Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -33,7 +33,7 @@
 #include "BBSThreadList.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: BBSThreadVariableCreator.cpp 1945 2006-11-07 14:54:54Z svn $");
+SOURCE_INFO_ADD("$Id: BBSThreadVariableCreator.cpp 2327 2006-12-29 18:07:16Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -186,7 +186,7 @@ inline TemplateVariable::variable_t *
 BBSThreadVariableCreator::create_info(apr_pool_t *pool,
                                       BBSThread::info_t *thread_info,
                                       void *var_memory,
-                                      void *sca_memory) const throw()
+                                      void *sca_memory) const
 {
     variable_t *info_var;
     scalar_t *info_sca;
@@ -218,7 +218,7 @@ inline void
 BBSThreadVariableCreator::set_range(BBSThread::info_t *thread_info,
                                     apr_size_t comment_count,
                                     BBSCommentIterator::range_t *range,
-                                    apr_size_t *range_count) const throw()
+                                    apr_size_t *range_count) const
 {
     if (thread_info->comment_count == 1) {
         *range_count = 1;
@@ -302,7 +302,7 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
     tmpl_file_path = argv[2];
 
     if (!is_exist(pool, data_dir_path)) {
-        THROW(MESSAGE_DAT_DIR_NOT_FOUND);
+        THROW(MESSAGE_DATA_DIR_NOT_FOUND);
     }
     if (!is_exist(pool, tmpl_file_path)) {
         THROW(MESSAGE_TMPL_FILE_NOT_FOUND);
