@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MessageDigest5.cpp 1903 2006-10-29 13:13:56Z svn $
+ * $Id: MessageDigest5.cpp 2317 2006-12-28 16:07:10Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -35,7 +35,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: MessageDigest5.cpp 1903 2006-10-29 13:13:56Z svn $");
+SOURCE_INFO_ADD("$Id: MessageDigest5.cpp 2317 2006-12-28 16:07:10Z svn $");
 
 #ifdef DEBUG
 #define REQUIRE_UPDATE_STATE(state)                             \
@@ -74,9 +74,6 @@ MessageDigest5::MessageDigest5()
 }
 
 void MessageDigest5::update(const apr_byte_t *input, apr_size_t size)
-#ifndef DEBUG
-    throw()
-#endif
 {
     apr_size_t gap;
     apr_size_t read_size;
@@ -110,9 +107,6 @@ void MessageDigest5::update(const apr_byte_t *input, apr_size_t size)
 }
 
 void MessageDigest5::finish()
-#ifndef DEBUG
-    throw()
-#endif
 {
     apr_byte_t input_size[8];
     apr_size_t padding_size;
@@ -134,10 +128,6 @@ void MessageDigest5::finish()
 }
 
 const char *MessageDigest5::c_str()
-#ifndef DEBUG
-    throw()
-#endif
-
 {
     REQUIRE_UPDATE_STATE(is_finish_);
 
@@ -149,31 +139,31 @@ const char *MessageDigest5::c_str()
  * private メソッド
  *****************************************************************************/
 inline apr_uint32_t MessageDigest5::calc_f(apr_uint32_t x, apr_uint32_t y,
-                                           apr_uint32_t z) throw()
+                                           apr_uint32_t z)
 {
     return z ^ (x & (y ^ z));
 }
 
 inline apr_uint32_t MessageDigest5::calc_g(apr_uint32_t x, apr_uint32_t y,
-                                           apr_uint32_t z) throw()
+                                           apr_uint32_t z)
 {
     return (x & z) | (y & ~z);
 }
 
 inline apr_uint32_t MessageDigest5::calc_h(apr_uint32_t x, apr_uint32_t y,
-                                           apr_uint32_t z) throw()
+                                           apr_uint32_t z)
 {
     return x ^ y ^ z;
 }
 
 inline apr_uint32_t MessageDigest5::calc_i(apr_uint32_t x, apr_uint32_t y,
-                                           apr_uint32_t z) throw()
+                                           apr_uint32_t z)
 {
     return y ^ (x | ~z);
 }
 
 inline apr_uint32_t MessageDigest5::rotl(apr_uint32_t value,
-                                         apr_uint32_t shift) throw()
+                                         apr_uint32_t shift)
 {
     // GCC は次の式を単一の roll 命令に変換してくれるようです
     return (value << shift) | (value >> (32-shift));
@@ -182,7 +172,7 @@ inline apr_uint32_t MessageDigest5::rotl(apr_uint32_t value,
 inline apr_uint32_t MessageDigest5::round1(apr_uint32_t a, apr_uint32_t b,
                                            apr_uint32_t c, apr_uint32_t d,
                                            apr_uint32_t x, apr_uint32_t s,
-                                           apr_uint32_t t) throw()
+                                           apr_uint32_t t)
 {
     return b + rotl(a + calc_f(b, c, d) + x + t, s);
 }
@@ -190,7 +180,7 @@ inline apr_uint32_t MessageDigest5::round1(apr_uint32_t a, apr_uint32_t b,
 inline apr_uint32_t MessageDigest5::round2(apr_uint32_t a, apr_uint32_t b,
                                            apr_uint32_t c, apr_uint32_t d,
                                            apr_uint32_t x, apr_uint32_t s,
-                                           apr_uint32_t t) throw()
+                                           apr_uint32_t t)
 {
     return b + rotl(a + calc_g(b, c, d) + x + t, s);
 }
@@ -198,7 +188,7 @@ inline apr_uint32_t MessageDigest5::round2(apr_uint32_t a, apr_uint32_t b,
 inline apr_uint32_t MessageDigest5::round3(apr_uint32_t a, apr_uint32_t b,
                                            apr_uint32_t c, apr_uint32_t d,
                                            apr_uint32_t x, apr_uint32_t s,
-                                           apr_uint32_t t) throw()
+                                           apr_uint32_t t)
 {
     return b + rotl(a + calc_h(b, c, d) + x + t, s);
 }
@@ -206,13 +196,13 @@ inline apr_uint32_t MessageDigest5::round3(apr_uint32_t a, apr_uint32_t b,
 inline apr_uint32_t MessageDigest5::round4(apr_uint32_t a, apr_uint32_t b,
                                            apr_uint32_t c, apr_uint32_t d,
                                            apr_uint32_t x, apr_uint32_t s,
-                                           apr_uint32_t t) throw()
+                                           apr_uint32_t t)
 {
     return b + rotl(a + calc_i(b, c, d) + x + t, s);
 }
 
 void MessageDigest5::byte2int(const apr_byte_t *bytes,
-                              apr_uint32_t *ints) throw()
+                              apr_uint32_t *ints)
 {
     for (apr_size_t i = 0; i < 16; i++) {
         ints[i] = ((apr_uint32_t)bytes[i*4    ]) |
@@ -223,7 +213,7 @@ void MessageDigest5::byte2int(const apr_byte_t *bytes,
 }
 
 void MessageDigest5::int2byte(const apr_uint32_t *ints, apr_size_t size,
-                              apr_byte_t *bytes) throw()
+                              apr_byte_t *bytes)
 {
     for (apr_size_t i = 0; i < size; i++) {
         bytes[i*4    ] = (ints[i]      ) & 0xff;
@@ -233,7 +223,7 @@ void MessageDigest5::int2byte(const apr_uint32_t *ints, apr_size_t size,
     }
 }
 
-void MessageDigest5::process(const apr_byte_t block[64]) throw()
+void MessageDigest5::process(const apr_byte_t block[64])
 {
     apr_uint32_t a, b, c, d;
     apr_uint32_t x[16];
@@ -245,70 +235,70 @@ void MessageDigest5::process(const apr_byte_t block[64]) throw()
 
     byte2int(block, x);
 
-    a = round1(a, b, c, d, x[ 0],  7, 0xd76aa478);
-    d = round1(d, a, b, c, x[ 1], 12, 0xe8c7b756);
-    c = round1(c, d, a, b, x[ 2], 17, 0x242070db);
-    b = round1(b, c, d, a, x[ 3], 22, 0xc1bdceee);
-    a = round1(a, b, c, d, x[ 4],  7, 0xf57c0faf);
-    d = round1(d, a, b, c, x[ 5], 12, 0x4787c62a);
-    c = round1(c, d, a, b, x[ 6], 17, 0xa8304613);
-    b = round1(b, c, d, a, x[ 7], 22, 0xfd469501);
-    a = round1(a, b, c, d, x[ 8],  7, 0x698098d8);
-    d = round1(d, a, b, c, x[ 9], 12, 0x8b44f7af);
-    c = round1(c, d, a, b, x[10], 17, 0xffff5bb1);
-    b = round1(b, c, d, a, x[11], 22, 0x895cd7be);
-    a = round1(a, b, c, d, x[12],  7, 0x6b901122);
-    d = round1(d, a, b, c, x[13], 12, 0xfd987193);
-    c = round1(c, d, a, b, x[14], 17, 0xa679438e);
-    b = round1(b, c, d, a, x[15], 22, 0x49b40821);
-    a = round2(a, b, c, d, x[ 1],  5, 0xf61e2562);
-    d = round2(d, a, b, c, x[ 6],  9, 0xc040b340);
-    c = round2(c, d, a, b, x[11], 14, 0x265e5a51);
-    b = round2(b, c, d, a, x[ 0], 20, 0xe9b6c7aa);
-    a = round2(a, b, c, d, x[ 5],  5, 0xd62f105d);
-    d = round2(d, a, b, c, x[10],  9, 0x02441453);
-    c = round2(c, d, a, b, x[15], 14, 0xd8a1e681);
-    b = round2(b, c, d, a, x[ 4], 20, 0xe7d3fbc8);
-    a = round2(a, b, c, d, x[ 9],  5, 0x21e1cde6);
-    d = round2(d, a, b, c, x[14],  9, 0xc33707d6);
-    c = round2(c, d, a, b, x[ 3], 14, 0xf4d50d87);
-    b = round2(b, c, d, a, x[ 8], 20, 0x455a14ed);
-    a = round2(a, b, c, d, x[13],  5, 0xa9e3e905);
-    d = round2(d, a, b, c, x[ 2],  9, 0xfcefa3f8);
-    c = round2(c, d, a, b, x[ 7], 14, 0x676f02d9);
-    b = round2(b, c, d, a, x[12], 20, 0x8d2a4c8a);
-    a = round3(a, b, c, d, x[ 5],  4, 0xfffa3942);
-    d = round3(d, a, b, c, x[ 8], 11, 0x8771f681);
-    c = round3(c, d, a, b, x[11], 16, 0x6d9d6122);
-    b = round3(b, c, d, a, x[14], 23, 0xfde5380c);
-    a = round3(a, b, c, d, x[ 1],  4, 0xa4beea44);
-    d = round3(d, a, b, c, x[ 4], 11, 0x4bdecfa9);
-    c = round3(c, d, a, b, x[ 7], 16, 0xf6bb4b60);
-    b = round3(b, c, d, a, x[10], 23, 0xbebfbc70);
-    a = round3(a, b, c, d, x[13],  4, 0x289b7ec6);
-    d = round3(d, a, b, c, x[ 0], 11, 0xeaa127fa);
-    c = round3(c, d, a, b, x[ 3], 16, 0xd4ef3085);
-    b = round3(b, c, d, a, x[ 6], 23, 0x04881d05);
-    a = round3(a, b, c, d, x[ 9],  4, 0xd9d4d039);
-    d = round3(d, a, b, c, x[12], 11, 0xe6db99e5);
-    c = round3(c, d, a, b, x[15], 16, 0x1fa27cf8);
-    b = round3(b, c, d, a, x[ 2], 23, 0xc4ac5665);
-    a = round4(a, b, c, d, x[ 0],  6, 0xf4292244);
-    d = round4(d, a, b, c, x[ 7], 10, 0x432aff97);
-    c = round4(c, d, a, b, x[14], 15, 0xab9423a7);
-    b = round4(b, c, d, a, x[ 5], 21, 0xfc93a039);
-    a = round4(a, b, c, d, x[12],  6, 0x655b59c3);
-    d = round4(d, a, b, c, x[ 3], 10, 0x8f0ccc92);
-    c = round4(c, d, a, b, x[10], 15, 0xffeff47d);
-    b = round4(b, c, d, a, x[ 1], 21, 0x85845dd1);
-    a = round4(a, b, c, d, x[ 8],  6, 0x6fa87e4f);
-    d = round4(d, a, b, c, x[15], 10, 0xfe2ce6e0);
-    c = round4(c, d, a, b, x[ 6], 15, 0xa3014314);
-    b = round4(b, c, d, a, x[13], 21, 0x4e0811a1);
-    a = round4(a, b, c, d, x[ 4],  6, 0xf7537e82);
-    d = round4(d, a, b, c, x[11], 10, 0xbd3af235);
-    c = round4(c, d, a, b, x[ 2], 15, 0x2ad7d2bb);
-    b = round4(b, c, d, a, x[ 9], 21, 0xeb86d391);
+    a = round1(a, b, c, d, x[ 0],  7, 0xd76aa478U);
+    d = round1(d, a, b, c, x[ 1], 12, 0xe8c7b756U);
+    c = round1(c, d, a, b, x[ 2], 17, 0x242070dbU);
+    b = round1(b, c, d, a, x[ 3], 22, 0xc1bdceeeU);
+    a = round1(a, b, c, d, x[ 4],  7, 0xf57c0fafU);
+    d = round1(d, a, b, c, x[ 5], 12, 0x4787c62aU);
+    c = round1(c, d, a, b, x[ 6], 17, 0xa8304613U);
+    b = round1(b, c, d, a, x[ 7], 22, 0xfd469501U);
+    a = round1(a, b, c, d, x[ 8],  7, 0x698098d8U);
+    d = round1(d, a, b, c, x[ 9], 12, 0x8b44f7afU);
+    c = round1(c, d, a, b, x[10], 17, 0xffff5bb1U);
+    b = round1(b, c, d, a, x[11], 22, 0x895cd7beU);
+    a = round1(a, b, c, d, x[12],  7, 0x6b901122U);
+    d = round1(d, a, b, c, x[13], 12, 0xfd987193U);
+    c = round1(c, d, a, b, x[14], 17, 0xa679438eU);
+    b = round1(b, c, d, a, x[15], 22, 0x49b40821U);
+    a = round2(a, b, c, d, x[ 1],  5, 0xf61e2562U);
+    d = round2(d, a, b, c, x[ 6],  9, 0xc040b340U);
+    c = round2(c, d, a, b, x[11], 14, 0x265e5a51U);
+    b = round2(b, c, d, a, x[ 0], 20, 0xe9b6c7aaU);
+    a = round2(a, b, c, d, x[ 5],  5, 0xd62f105dU);
+    d = round2(d, a, b, c, x[10],  9, 0x02441453U);
+    c = round2(c, d, a, b, x[15], 14, 0xd8a1e681U);
+    b = round2(b, c, d, a, x[ 4], 20, 0xe7d3fbc8U);
+    a = round2(a, b, c, d, x[ 9],  5, 0x21e1cde6U);
+    d = round2(d, a, b, c, x[14],  9, 0xc33707d6U);
+    c = round2(c, d, a, b, x[ 3], 14, 0xf4d50d87U);
+    b = round2(b, c, d, a, x[ 8], 20, 0x455a14edU);
+    a = round2(a, b, c, d, x[13],  5, 0xa9e3e905U);
+    d = round2(d, a, b, c, x[ 2],  9, 0xfcefa3f8U);
+    c = round2(c, d, a, b, x[ 7], 14, 0x676f02d9U);
+    b = round2(b, c, d, a, x[12], 20, 0x8d2a4c8aU);
+    a = round3(a, b, c, d, x[ 5],  4, 0xfffa3942U);
+    d = round3(d, a, b, c, x[ 8], 11, 0x8771f681U);
+    c = round3(c, d, a, b, x[11], 16, 0x6d9d6122U);
+    b = round3(b, c, d, a, x[14], 23, 0xfde5380cU);
+    a = round3(a, b, c, d, x[ 1],  4, 0xa4beea44U);
+    d = round3(d, a, b, c, x[ 4], 11, 0x4bdecfa9U);
+    c = round3(c, d, a, b, x[ 7], 16, 0xf6bb4b60U);
+    b = round3(b, c, d, a, x[10], 23, 0xbebfbc70U);
+    a = round3(a, b, c, d, x[13],  4, 0x289b7ec6U);
+    d = round3(d, a, b, c, x[ 0], 11, 0xeaa127faU);
+    c = round3(c, d, a, b, x[ 3], 16, 0xd4ef3085U);
+    b = round3(b, c, d, a, x[ 6], 23, 0x04881d05U);
+    a = round3(a, b, c, d, x[ 9],  4, 0xd9d4d039U);
+    d = round3(d, a, b, c, x[12], 11, 0xe6db99e5U);
+    c = round3(c, d, a, b, x[15], 16, 0x1fa27cf8U);
+    b = round3(b, c, d, a, x[ 2], 23, 0xc4ac5665U);
+    a = round4(a, b, c, d, x[ 0],  6, 0xf4292244U);
+    d = round4(d, a, b, c, x[ 7], 10, 0x432aff97U);
+    c = round4(c, d, a, b, x[14], 15, 0xab9423a7U);
+    b = round4(b, c, d, a, x[ 5], 21, 0xfc93a039U);
+    a = round4(a, b, c, d, x[12],  6, 0x655b59c3U);
+    d = round4(d, a, b, c, x[ 3], 10, 0x8f0ccc92U);
+    c = round4(c, d, a, b, x[10], 15, 0xffeff47dU);
+    b = round4(b, c, d, a, x[ 1], 21, 0x85845dd1U);
+    a = round4(a, b, c, d, x[ 8],  6, 0x6fa87e4fU);
+    d = round4(d, a, b, c, x[15], 10, 0xfe2ce6e0U);
+    c = round4(c, d, a, b, x[ 6], 15, 0xa3014314U);
+    b = round4(b, c, d, a, x[13], 21, 0x4e0811a1U);
+    a = round4(a, b, c, d, x[ 4],  6, 0xf7537e82U);
+    d = round4(d, a, b, c, x[11], 10, 0xbd3af235U);
+    c = round4(c, d, a, b, x[ 2], 15, 0x2ad7d2bbU);
+    b = round4(b, c, d, a, x[ 9], 21, 0xeb86d391U);
 
     state_[0] += a;
     state_[1] += b;
@@ -316,7 +306,7 @@ void MessageDigest5::process(const apr_byte_t block[64]) throw()
     state_[3] += d;
 }
 
-void MessageDigest5::create_digest() throw()
+void MessageDigest5::create_digest()
 {
     int2byte(state_, 4, digest_bytes_);
 
