@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: NichDatParser.cpp 1943 2006-11-07 13:09:46Z svn $
+ * $Id: NichDatParser.cpp 2063 2006-11-24 14:09:34Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -41,7 +41,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: NichDatParser.cpp 1943 2006-11-07 13:09:46Z svn $");
+SOURCE_INFO_ADD("$Id: NichDatParser.cpp 2063 2006-11-24 14:09:34Z svn $");
 
 const char NichDatParser::LINE_SEPARATOR[]       = "\n";
 const char NichDatParser::COLUMN_SEPARATOR[]     = "<>";
@@ -367,7 +367,7 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
     data_file_path = argv[1];
 
     if (!is_exist(pool, data_file_path)) {
-        THROW(MESSAGE_DAT_FILE_NOT_FOUND);
+        THROW(MESSAGE_DATA_FILE_NOT_FOUND);
     }
 
     File data_file(pool, data_file_path);
