@@ -22,18 +22,19 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostFlowController.cpp 1898 2006-10-26 17:46:14Z svn $
+ * $Id: PostFlowController.cpp 2317 2006-12-28 16:07:10Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
 
+#include "apr_strings.h"
+
 #include "PostFlowController.h"
+#include "ReadLocker.h"
+#include "WriteLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: PostFlowController.cpp 1898 2006-10-26 17:46:14Z svn $");
-
-const apr_size_t PostFlowController::BUSY   = 1;
-const apr_size_t PostFlowController::FREE   = 0;
+SOURCE_INFO_ADD("$Id: PostFlowController.cpp 2317 2006-12-28 16:07:10Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -43,45 +44,28 @@ PostFlowController::PostFlowController(apr_size_t min_post_interval_sec)
     poster_top_(0),
     poster_tail_(0)
 {
-    apr_atomic_set(&lock_, FREE);
+    (void)apr_atomic_set(&lock_, ReadWriteLocker::NOT_LOCKER);
 }
 
-bool PostFlowController::can_post(const char *ip_address)
+bool PostFlowController::can_post(apr_sockaddr_t *sockaddr)
 {
-    apr_time_t last_post_time;
-    apr_time_t post_interval_time;
-    bool can_post;
+    apr_time_t time_limit;
 
-    while (apr_atomic_cas(&lock_, BUSY, FREE) != FREE);
+    ReadLocker lock(&lock_);
 
     // MEMO: 短時間の間に異なる ARRAY_SIZE_OF(poster_list_) 個の IP ア
     // ドレスから投稿があった場合，制限に漏れが生じる．
 
-    last_post_time = poster_list_is_contain
-        (ip_address, static_cast<char>(strlen(ip_address) & 0xff));
+    time_limit = apr_time_now() - min_post_interval_time_;
 
-    if (last_post_time == 0) {
-        can_post = true;
-    } else {
-        post_interval_time = apr_time_now() - last_post_time;
-
-        if (post_interval_time > min_post_interval_time_) {
-            can_post = true;
-        } else {
-            can_post = false;
-        }
-    }
-
-    while (apr_atomic_cas(&lock_, FREE, BUSY) != BUSY);
-
-    return can_post;
+    return poster_list_is_contain(sockaddr, time_limit);
 }
 
-void PostFlowController::regist_post(const char *ip_address)
+void PostFlowController::regist_post(apr_sockaddr_t *sockaddr)
 {
-    while (apr_atomic_cas(&lock_, BUSY, FREE) != FREE);
-    poster_list_add(ip_address, static_cast<char>(strlen(ip_address) & 0xff));
-    while (apr_atomic_cas(&lock_, FREE, BUSY) != BUSY);
+    WriteLocker lock(&lock_);
+
+    poster_list_add(sockaddr);
 }
 
 PostFlowController *PostFlowController::get_instance(apr_shm_t *shm,
@@ -107,28 +91,34 @@ apr_size_t PostFlowController::get_memory_size()
     return sizeof(PostFlowController);
 }
 
-void PostFlowController::dump_list(PostFlowController *flow_controller)
+const char *PostFlowController::dump_list(apr_pool_t *pool,
+                                          PostFlowController *flow_controller)
 {
     apr_size_t i;
+    const char *dump;
 
     if (flow_controller->poster_top_ == flow_controller->poster_tail_) {
-        return;
+        return "";
     }
 
     i = flow_controller->poster_top_;
+    dump = "";
     do {
-        dump_poster(flow_controller->poster_list_ + i);
+        dump = apr_pstrcat
+            (pool, dump, dump_poster(pool, flow_controller->poster_list_ + i),
+             NULL);
     } while ((i = (i == 0)
               ? (ARRAY_SIZE_OF(flow_controller->poster_list_)-1)
               : (i-1)) != flow_controller->poster_tail_);
+
+    return dump;
 }
 
 
 /******************************************************************************
  * private メソッド
  *****************************************************************************/
-void PostFlowController::poster_list_add(const char *ip_address,
-                                         char ip_address_length)
+void PostFlowController::poster_list_add(apr_sockaddr_t *sockaddr)
 {
     poster_top_++;
     if (poster_top_ == ARRAY_SIZE_OF(poster_list_)) {
@@ -141,9 +131,8 @@ void PostFlowController::poster_list_add(const char *ip_address,
         }
     }
 
-    poster_list_[poster_top_].ip_address[0] = ip_address_length;
-    memcpy(&(poster_list_[poster_top_].ip_address[1]), ip_address,
-           ip_address_length);
+    strncpy(poster_list_[poster_top_].paddress, get_paddress(sockaddr),
+            MAX_PADDRESS_SIZE - 1);
     poster_list_[poster_top_].time = apr_time_now();
 }
 
@@ -163,36 +152,37 @@ void PostFlowController::poster_list_clean()
     poster_tail_ = i;
 }
 
-apr_time_t PostFlowController::poster_list_is_contain(const char *ip_address,
-                                                      char ip_address_length) const
+bool PostFlowController::poster_list_is_contain(apr_sockaddr_t *sockaddr,
+                                                apr_time_t time_limit) const
 {
+    const char *paddress;
     apr_size_t i;
 
     if (poster_top_ == poster_tail_) {
-        return 0;
+        return true;
     }
 
+    paddress = get_paddress(sockaddr);
+
     i = poster_top_;
     do {
-        if (poster_list_[i].ip_address[0] != ip_address_length) {
-            continue;
+        if (poster_list_[i].time < time_limit) {
+            return true;
         }
-
-        if (memcmp(ip_address, &(poster_list_[i].ip_address[1]),
-                   ip_address_length) != 0) {
-            continue;
+        if (is_address_match(poster_list_[i].paddress, paddress)) {
+            return false;
         }
-        return poster_list_[i].time;
     } while ((i = (i == 0)
               ? (ARRAY_SIZE_OF(poster_list_)-1)
               : (i-1)) != poster_tail_);
 
-    return 0;
+    return true;
 }
 
-void PostFlowController::dump_poster(poster_t *poster)
+const char *PostFlowController::dump_poster(apr_pool_t *pool, poster_t *poster)
 {
-    cerr.write(&(poster->ip_address[1]), poster->ip_address[0]) << endl;
+    return apr_psprintf(pool, "%24s : %" APR_TIME_T_FMT "\n",
+                        &(poster->paddress[1]), poster->time);
 }
 
 
@@ -202,33 +192,50 @@ void PostFlowController::dump_poster(poster_t *poster)
 #ifdef DEBUG_PostFlowController
 #include "TestRunner.h"
 
-const char DUMMY_IP_ADDRESS[]           = "127.0.0.1";
-const apr_time_t MIN_POST_INTERVAL_SEC  = 10;
-const apr_size_t ATTACK_COUNT           = 10000;
+const char DUMMY_ADDRESS[]              = "127.0.0.1";
+const apr_time_t MIN_POST_INTERVAL_SEC  = 1;
+const apr_size_t ATTACK_COUNT           = 100;
 
 void show_usage(const char *prog_name)
 {
     cerr << "Usage: " << prog_name << endl;
 }
 
-void run_can_post(PostFlowController *flow_controller)
+void run_can_post(PostFlowController *flow_controller,
+                  apr_sockaddr_t *sockaddr)
 {
+    apr_size_t i;
+
     show_test_name("can_post");
 
-    for (apr_size_t i = 0; i < ATTACK_COUNT; i++) {
-        flow_controller->can_post(DUMMY_IP_ADDRESS);
+    flow_controller->regist_post(sockaddr);
+
+    for (i = 0; i < ATTACK_COUNT; i++) {
+        if (flow_controller->can_post(sockaddr)) {
+            break;
+        }
+        apr_sleep(100000);
+    }
+
+    if ((i == 0) || (i == ATTACK_COUNT)) {
+        THROW(MESSAGE_BUG_FOUND);
     }
 }
 
 void run_all(apr_pool_t *pool, int argc, const char * const *argv)
 {
+    apr_sockaddr_t *sockaddr;
+
     if (argc != 1) {
         THROW(MESSAGE_ARGUMENT_INVALID);
     }
 
     PostFlowController flow_controller(MIN_POST_INTERVAL_SEC);
     show_line();
-    run_can_post(&flow_controller);
+
+    sockaddr = get_sockaddr(pool, DUMMY_ADDRESS);
+
+    run_can_post(&flow_controller, sockaddr);
 }
 
 #endif
