@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ReadWriteAttacker.cpp 1981 2006-11-12 06:40:26Z svn $
+ * $Id: ReadWriteAttacker.cpp 2047 2006-11-23 18:57:33Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -44,7 +44,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: ReadWriteAttacker.cpp 1981 2006-11-12 06:40:26Z svn $");
+SOURCE_INFO_ADD("$Id: ReadWriteAttacker.cpp 2047 2006-11-23 18:57:33Z svn $");
 
 #define AS_THREAD_START(pointer)    reinterpret_cast<apr_thread_start_t>(pointer)
 
@@ -402,7 +402,7 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
     read_worker_count = atoi(argv[2]);
 
     if (!is_exist(pool, data_dir_path)) {
-        THROW(MESSAGE_DAT_DIR_NOT_FOUND);
+        THROW(MESSAGE_DATA_DIR_NOT_FOUND);
     }
 
     manager_shm = create_shm(pool, BBSThreadManager::get_memory_size());
