@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateExecutor.cpp 1774 2006-10-09 04:13:54Z svn $
+ * $Id: TemplateExecutor.cpp 2320 2006-12-28 16:35:12Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -38,8 +38,10 @@
 #include "Message.h"
 #include "SourceInfo.h"
 
+using namespace std;
+
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: TemplateExecutor.cpp 1774 2006-10-09 04:13:54Z svn $");
+SOURCE_INFO_ADD("$Id: TemplateExecutor.cpp 2320 2006-12-28 16:35:12Z svn $");
 #endif
 
 #ifdef DEBUG_TemplateExecutor
@@ -663,19 +665,19 @@ TemplateExecutor<W>::create_scalar()
 
 template<class W>
 TEMPLATE_EXECUTOR_INLINE void TemplateExecutor<W>::print(const char *str,
-                                                         apr_size_t length) throw()
+                                                         apr_size_t length)
 {
     writer_.write(str, length);
 }
 
 template<class W>
-TEMPLATE_EXECUTOR_INLINE void TemplateExecutor<W>::print(const char *str) throw()
+TEMPLATE_EXECUTOR_INLINE void TemplateExecutor<W>::print(const char *str)
 {
     writer_.write(str);
 }
 
 template<class W>
-TEMPLATE_EXECUTOR_INLINE void TemplateExecutor<W>::print(int i) throw()
+TEMPLATE_EXECUTOR_INLINE void TemplateExecutor<W>::print(int i)
 {
     writer_.write(i);
 }
@@ -685,13 +687,14 @@ TEMPLATE_EXECUTOR_INLINE void TemplateExecutor<W>::print(int i) throw()
  * テスト
  *****************************************************************************/
 #ifdef DEBUG_TemplateExecutor
-#include "TestRunner.h"
 #include "BBSTemplate.h"
 #include "BBSCommentVariableCreator.h"
 #include "BBSCommentIterator.h"
 #include "TemplateVariableCreator.h"
 #include "CGIResponseWriter.h"
 
+#include "TestRunner.h"
+
 typedef TemplateExecutor<CGIResponseWriter> TemplateExecutorImpl;
 
 static const apr_size_t COMMENT_COUNT   = 10;
@@ -752,7 +755,7 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
     }
 
     if (!is_exist(pool, data_dir_path)) {
-        THROW(MESSAGE_DAT_DIR_NOT_FOUND);
+        THROW(MESSAGE_DATA_DIR_NOT_FOUND);
     }
     if (!is_exist(pool, tmpl_file_path)) {
         THROW(MESSAGE_TMPL_FILE_NOT_FOUND);
