@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateLexer.cpp 1773 2006-10-09 01:27:02Z svn $
+ * $Id: TemplateLexer.cpp 2317 2006-12-28 16:07:10Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -42,14 +42,17 @@
 #include "TemporaryPool.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: TemplateLexer.cpp 1773 2006-10-09 01:27:02Z svn $");
+using namespace std;
+
+SOURCE_INFO_ADD("$Id: TemplateLexer.cpp 2317 2006-12-28 16:07:10Z svn $");
 
 #define AS_TOKEN(pointer)           reinterpret_cast<token_t *>(pointer)
 #define AS_TOKEN_P(pointer)         reinterpret_cast<token_t **>(pointer)
 
 #define IS_INPUT_MATCH(pattern)                                     \
         (((input_.top + LITERAL_STRLEN(pattern)) <= input_.end) &&  \
-         (strncmp(input_.top, pattern, LITERAL_STRLEN(pattern)) == 0))
+         (strncmp(input_.top, pattern, LITERAL_STRLEN(pattern)) == 0) && \
+         (!isalnum(*(input_.top + LITERAL_STRLEN(pattern)))))
 #define PUSH_TOKEN_AND_FORWARD(type, pattern)                       \
     push_token(create_token(type));                                 \
     input_.top += LITERAL_STRLEN(pattern)
@@ -440,7 +443,7 @@ bool TemplateLexer::get_next_str_token()
     push_token(create_token(PRINT));
 
     while ((input_.top != str_end) &&
-           ((var_start = strnchr((char *)input_.top, str_end - input_.top,
+           ((var_start = strnchr(input_.top, str_end - input_.top,
                                  VARIABLE_C)) != NULL) && // 変数記号を探索
            !((var_start != input_.top) && // 直前にエスケープがある場合を除外
              *(var_start-1) == ESCAPE_C)) {
