@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: cgi_fast_bbs.cpp 1981 2006-11-12 06:40:26Z svn $
+ * $Id: cgi_fast_bbs.cpp 2029 2006-11-23 11:12:51Z svn $
  *****************************************************************************/
 
 /**
@@ -50,7 +50,7 @@
 #define RESPONSE_TYPE_CGI
 #include "fast_bbs_handler.cpp"
 
-SOURCE_INFO_ADD("$Id: cgi_fast_bbs.cpp 1981 2006-11-12 06:40:26Z svn $");
+SOURCE_INFO_ADD("$Id: cgi_fast_bbs.cpp 2029 2006-11-23 11:12:51Z svn $");
 
 static const char *CON_FILE_PATH    = "./fast_bbs.conf";
 
@@ -63,7 +63,7 @@ void bbs_main(apr_pool_t *pool)
     config->init();
 
     if (apr_env_get(&path_info, "PATH_INFO", pool) != APR_SUCCESS) {
-        path_info = "";
+        path_info = const_cast<char *>("");
     }
 
     CGIResponse::Handle r(pool);
