@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: fast_bbs_handler.cpp 1951 2006-11-08 11:31:58Z svn $
+ * $Id: fast_bbs_handler.cpp 2328 2006-12-29 18:52:20Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -55,7 +55,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: fast_bbs_handler.cpp 1951 2006-11-08 11:31:58Z svn $");
+SOURCE_INFO_ADD("$Id: fast_bbs_handler.cpp 2328 2006-12-29 18:52:20Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command) \
@@ -201,9 +201,9 @@ static int index(typename Response::Handle *r, BBSConfig *config,
               bcomment_iter, config->get_thread_manager(),
               info_list, info_list_size, VIW_ABSTRACT_COMMENT_COUNT));
 
-        try {
-            var_creator.create(THREAD_LIST_SIZE_VAR_NAME, info_list_size);
+        var_creator.create(THREAD_LIST_SIZE_VAR_NAME, info_list_size);
 
+        try {
             TemplateExecutor<typename Response::Writer> executor(r->pool, o);
 
             executor.exec(tmpl->get_node_tree(), var_creator.get_variables(),
@@ -361,6 +361,10 @@ static int file(typename Response::Handle *r, BBSConfig *config,
     thread_id = static_cast<apr_size_t>
         (apr_atoi64(get_word(r->pool, &thread_id_str, FILE_TOKEN_SEPARATOR[0])));
 
+    if (strlen(file_name) == 0) {
+        return HTTP_BAD_REQUEST;
+    }
+
     try {
         file_path = BBSThreadIO::get_file_path(r->pool, config->file_dir_path,
                                                thread_id, file_name);
@@ -453,7 +457,6 @@ static int post_comment(typename Response::Handle *r, BBSConfig *config,
                         const char *arg)
 {
     int status;
-    apr_array_header_t *content_array;
     const char *image_temp_path;
 
     if (!Response::is_post_method(r)) {
@@ -464,7 +467,7 @@ static int post_comment(typename Response::Handle *r, BBSConfig *config,
         return status;
     }
 
-    if (!can_post(config, Response::get_remote_ip(r))) {
+    if (!can_post(config, Response::get_remote_addr(r))) {
         return error<Response>(r, config, MESSAGE_POST_INTERVAL_TOO_SHORT);
     }
 
@@ -478,9 +481,10 @@ static int post_comment(typename Response::Handle *r, BBSConfig *config,
         const char *message;
         apr_time_t time;
         bool is_age;
-        RequestReader::progress_t progress;
+        RequestReader::post_progress_t progress;
         BBSThread::image_t image;
         apr_uint16_t comment_no;
+        apr_array_header_t *content_array;
 
         typename Response::Reader i(&progress, r);
         RFC1867Parser<typename Response::Reader> parser
@@ -496,16 +500,16 @@ static int post_comment(typename Response::Handle *r, BBSConfig *config,
              &thread_id, &name, &trip, &email, &message,
              &image, &image_temp_path, &time, &is_age);
 
-
         comment_no = config->get_thread_manager()->add_comment
             (thread_id, name, trip, email, message, &image, time, is_age);
 
+        // TODO: この処理は BBSThreadManager の中でした方がいい
         if (image.size != 0) {
             commit_image_file(r->pool, config->file_dir_path,
                               thread_id, comment_no, &image, image_temp_path);
         }
 
-        regist_post(config, Response::get_remote_ip(r));
+        regist_post(config, Response::get_remote_addr(r));
 
         return redirect<Response>
             (r, o,
@@ -535,7 +539,6 @@ static int post_thread(typename Response::Handle *r, BBSConfig *config,
                        const char *arg)
 {
     int status;
-    apr_array_header_t *content_array;
     const char *image_temp_path;
 
     if (!Response::is_post_method(r)) {
@@ -557,8 +560,9 @@ static int post_thread(typename Response::Handle *r, BBSConfig *config,
         const char *message;
         apr_time_t time;
         bool is_age;
-        RequestReader::progress_t progress;
+        RequestReader::post_progress_t progress;
         BBSThread::image_t image;
+        apr_array_header_t *content_array;
 
         typename Response::Reader i(&progress, r);
         RFC1867Parser<typename Response::Reader> parser
@@ -577,12 +581,13 @@ static int post_thread(typename Response::Handle *r, BBSConfig *config,
         thread_id = config->get_thread_manager()->create_thread
             (subject, name, trip, email, message, &image, time, is_age);
 
+        // TODO: この処理は BBSThreadManager の中でした方がいい
         if (image.size != 0) {
             commit_image_file(r->pool, config->file_dir_path,
                               thread_id, 1, &image, image_temp_path);
         }
 
-        regist_post(config, Response::get_remote_ip(r));
+        regist_post(config, Response::get_remote_addr(r));
 
         return redirect<Response>
             (r, o,
