@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: mod_fast_bbs.cpp 1937 2006-11-07 11:45:41Z svn $
+ * $Id: mod_fast_bbs.cpp 2019 2006-11-22 14:31:30Z svn $
  *****************************************************************************/
 
 /**
@@ -56,7 +56,7 @@
 #define RESPONSE_TYPE_APACHE
 #include "fast_bbs_handler.cpp"
 
-SOURCE_INFO_ADD("$Id: mod_fast_bbs.cpp 1937 2006-11-07 11:45:41Z svn $");
+SOURCE_INFO_ADD("$Id: mod_fast_bbs.cpp 2019 2006-11-22 14:31:30Z svn $");
 
 static const char *HANDLER_NAME = "fast_bbs";
 
@@ -65,7 +65,7 @@ static const char *HANDLER_NAME = "fast_bbs";
                   reinterpret_cast<const char*(*)()>(set_ ## member),   \
                   NULL, RSRC_CONF, BBSConfig::directive.desc)
 
-#define AS_BCONFIG(pointer)        reinterpret_cast<BBSConfig *>(pointer)
+#define AS_BCONFIG(pointer)         reinterpret_cast<BBSConfig *>(pointer)
 
 #define DIRECTIVE_HANDLER(member, value)                                \
     static const char *set_ ## member(cmd_parms *parms, void *mconfig,  \
@@ -268,7 +268,7 @@ static const command_rec fast_bbs_cmds[] = {
 };
 
 extern "C" {
-module AP_MODULE_DECLARE_DATA fast_bbs_module = {
+module EXPORT AP_MODULE_DECLARE_DATA fast_bbs_module = {
     STANDARD20_MODULE_STUFF,
     NULL,
     NULL,
