@@ -23,7 +23,7 @@
 # 3. This notice may not be removed or altered from any source
 #    distribution.
 #
-# $Id: mac_test.pl 1964 2006-11-11 17:30:22Z svn $
+# $Id: mac_test.pl 2031 2006-11-23 13:49:32Z svn $
 ###############################################################################
 
 use strict;
@@ -86,11 +86,11 @@ sub make_check {
     $exp->send('make clean' . "\n");
     $exp->expect(MAKE_TIMEOUT_SEC, MAC_HOSTNAME . '%');
 
-    $exp->send('make' . "\n");
-    $exp->expect(MAKE_TIMEOUT_SEC, MAC_HOSTNAME . '%');
+#     $exp->send('make' . "\n");
+#     $exp->expect(MAKE_TIMEOUT_SEC, MAC_HOSTNAME . '%');
 
-    $exp->send('make clean-obj' . "\n");
-    $exp->expect(MAKE_TIMEOUT_SEC, MAC_HOSTNAME . '%');
+#     $exp->send('make clean-obj' . "\n");
+#     $exp->expect(MAKE_TIMEOUT_SEC, MAC_HOSTNAME . '%');
 
     $exp->send('make cgi_fast_bbs.app' . "\n");
     $exp->expect(MAKE_TIMEOUT_SEC, MAC_HOSTNAME . '%');
