@@ -16,7 +16,7 @@ my $sf;
 
 GetOptions(\%args, "package=s", "mode=s", "version=s", "file=s");
 
-$pass = $ENV{'PASS'} || read_password('sourceforge pass: ', 0, 1);
+$pass = $ENV{'SF_PASS'} || read_password('sourceforge pass: ', 0, 1);
 
 $sf = WWW::SourceforgeJP->new(PROJECT);
 $sf->login(USER, $pass);
@@ -28,20 +28,20 @@ if ($args{'mode'} eq 'release') {
     $sf->create_release($args{'package'}, $args{'version'}, $args{'file'});
 } else {
     my @links = $sf->get_release_links();
-    my $src_link = (grep($_->text() =~ /^mod_fast_bbs-.*\.tgz$/, @links))[0];
-    my $win32_bin_link = (grep($_->text() =~ /^mod_fast_bbs-.*\.msi$/, @links))[0];
+    my $src_link = (grep($_->text() =~ /^mod_uploader-.*\.tgz$/, @links))[0];
+    my $win32_bin_link = (grep($_->text() =~ /^mod_uploader-.*\.msi$/, @links))[0];
 
     while (<>) {
-        if (/\* `mod_fast_bbs-\d+\.\d+\.\d+\.tgz/) {
+        if (/\* `mod_uploader-\d+\.\d+\.\d+\.tgz/) {
             print << "__HTML__";
 * `@{[$src_link->text()]}[0] <@{[$src_link->url()]}[0]>`_
 __HTML__
-        } elsif (/\* `mod_fast_bbs-\d+\.\d+\.\d+\.msi/) {
+        } elsif (/\* `mod_uploader-\d+\.\d+\.\d+\.msi/) {
             print << "__HTML__";
 * `@{[$win32_bin_link->text()]}[0] <@{[$win32_bin_link->url()]}[0]>`_
 __HTML__
         } else {
-            s/mod_fast_bbs-.*\.msi/$win32_bin_link->text()/eg;
+            s/mod_uploader-.*\.msi/$win32_bin_link->text()/eg;
             print;
         }
     }
